@@ -2,21 +2,8 @@ import os
 import signal
 import sys
 
-from functools import lru_cache
-
 from .service import Service
-
-
-HERE = os.path.abspath(os.path.dirname(__file__))
-PID_FILE = os.path.join(HERE, '.pid')
-
-
-def _file_pid():
-    if os.path.isfile(PID_FILE):
-        with open(PID_FILE, 'r') as f:
-            pid = int(f.read())
-        return pid
-    return None
+from .conf.settings import SETTINGS
 
 
 def _check_pid(pid): 
@@ -31,12 +18,12 @@ def _check_pid(pid):
 
 def launch_background_process(*args, **kwargs):
     # if there is a process already running, kill it
-    _pid = _file_pid()
+    _pid = SETTINGS.pid
     if _check_pid(_pid):
-        print("Background Snappy Zones process found: killing process...")
+        print("background Snappy Zones process found: killing process...")
         stop_background_process(_pid)
         
-    print("STARTING...")
+    print("starting...")
     try:
         pid = os.fork()
         if pid > 0:
@@ -46,23 +33,20 @@ def launch_background_process(*args, **kwargs):
         sys.exit(1)
 
     pid = str(os.getpid())
-
-    with open(os.path.join(HERE, '.pid'), 'w') as f:
-        f.write(pid)
-
-    print(f"STARTED PID: {pid}")
+    SETTINGS.pid = pid
+    print(f"started PID: {pid}")
     service = Service()
     service.listen()
     
 
 def stop_background_process(pid=None):
     if not pid:
-        pid = _file_pid()
+        pid = SETTINGS.pid
     if _check_pid(pid):
-        print(f"STOPPING...")
+        print(f"stopping...")
         os.kill(pid, signal.SIGTERM)
-        print(f"STOPPED PID: {pid}")
-        os.remove(PID_FILE)
+        print(f"stopped PID: {pid}")
+        os.remove(SETTINGS._pid_file)
     else:
         print(
             "No background process was found. "
